==> haskell-torrent-10000.1.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: torrent
version: 10000.1.1
id: torrent-10000.1.1-KopeGy7uN5q8jcrTmCxCCS
key: torrent-10000.1.1-KopeGy7uN5q8jcrTmCxCCS
license: BSD3
copyright: 2005-2007, Lemmih
maintainer: Joey Hess <id@joeyh.name>
synopsis: BitTorrent file parser and generater
category: Network
author: Lemmih <lemmih@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Torrent Data.Torrent.Scrape
abi: 9b91eddd65af478c34d57b12fd8b32bf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/torrent-10000.1.1
hs-libraries: HStorrent-10000.1.1-KopeGy7uN5q8jcrTmCxCCS
depends:
    base-4.10.1.0 bencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL binary-0.8.5.1
    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL=57ca7eba8ed5f31462ffaaa8f1cb2ec1
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html: /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-torrent-10000.1.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: torrent
version: 10000.1.1
id: torrent-10000.1.1-CNhrkx7ayr0FThD6XjBqve
key: torrent-10000.1.1-CNhrkx7ayr0FThD6XjBqve
license: BSD3
copyright: 2005-2007, Lemmih
maintainer: Joey Hess <id@joeyh.name>
synopsis: BitTorrent file parser and generater
category: Network
author: Lemmih <lemmih@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Torrent Data.Torrent.Scrape
abi: 6762d1486e6d089bc04d7e76c29b9891
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/torrent-10000.1.1
hs-libraries: HStorrent-10000.1.1-CNhrkx7ayr0FThD6XjBqve
depends:
    base-4.10.1.0 bencode-0.6.0.0-HjxHKkniC4T1KxAeGGP8Az binary-0.8.5.1
    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bencode-0.6.0.0-HjxHKkniC4T1KxAeGGP8Az=8ffd93c2978fdc24f5b10c5f4bcc8feb
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html: /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
